@@ -7,7 +7,7 @@ require Exporter;
 
 our ($VERSION, @ISA, @EXPORT, %ZIP_CM_MIN_VERSIONS);
 
-$VERSION = '2.017';
+$VERSION = '2.018';
 
 @ISA = qw(Exporter);
 
@@ -38,6 +38,8 @@ $VERSION = '2.017';
     ZIP_EXTRA_ID_ZIP64
     ZIP_EXTRA_ID_EXT_TIMESTAMP
     ZIP_EXTRA_ID_INFO_ZIP_UNIX2
+    ZIP_EXTRA_ID_INFO_ZIP_UNIXn
+    ZIP_EXTRA_ID_JAVA_EXE
 
     ZIP_OS_CODE_UNIX
     ZIP_OS_CODE_DEFAULT
